@@ -12,14 +12,18 @@ class LastSlot(BaseModel):
     ) -> datetime.datetime | None:
         if self.in_time is None:
             return None
-        return datetime.datetime.combine(self.date, self.in_time).astimezone(timezone)
+        return datetime.datetime.combine(self.date, self.in_time).replace(
+            tzinfo=timezone
+        )
 
     def get_checkout_timestamp(
         self, timezone: datetime.timezone
     ) -> datetime.datetime | None:
         if self.out_time is None:
             return None
-        return datetime.datetime.combine(self.date, self.out_time).astimezone(timezone)
+        return datetime.datetime.combine(self.date, self.out_time).replace(
+            tzinfo=timezone
+        )
 
 
 class LiveResponse(BaseModel):
